Stan Math Library: stan/math/prim/scal/fun/gamma_p.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

gamma_p.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_GAMMA_P_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_GAMMA_P_HPP
3
4 #include <boost/math/special_functions/gamma.hpp>
5
6 namespace stan {
7
8 namespace math {
9
52 // throws domain_error if x is at pole
53 double gamma_p(double x, double a) {
54 return boost::math::gamma_p(x, a);
55 }
56
57 }
58 }
59
60 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::gamma_p
var gamma_p(const double &a, const stan::math::var &b)
Definition: gamma_p.hpp:114
stan::math::gamma_p
fvar< T > gamma_p(const fvar< T > &x1, const fvar< T > &x2)
Definition: gamma_p.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.